==> jc-1.4.0.tar.gz: jas/Method.h <==
// public class jas.Method

// class file dependencies
// @dep_class fbdb68b05b612b08 jas_Method
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_Method_H_
#define _JC_jas_Method_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_ExceptAttr$object;
struct _jc_jas_GenericAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_Method$sub_refs	_jc_jas_Method$sub_refs;
typedef struct _jc_jas_Method$sub_nonrefs	_jc_jas_Method$sub_nonrefs;
typedef struct _jc_jas_Method$refs	_jc_jas_Method$refs;
typedef struct _jc_jas_Method$nonrefs	_jc_jas_Method$nonrefs;
typedef struct _jc_jas_Method$object	_jc_jas_Method$object;

typedef const struct _jc_jas_Method$vmethods	_jc_jas_Method$vmethods;
typedef const struct _jc_jas_Method$vtable	_jc_jas_Method$vtable;
typedef const struct _jc_jas_Method$vtype	_jc_jas_Method$vtype;

// Constructors
extern void _jc_jas_Method$method$_init$1b6040d9f9d8340f(_jc_env *, struct _jc_jas_Method$object *, jshort, struct _jc_jas_CP$object *, struct _jc_jas_CP$object *, struct _jc_jas_CodeAttr$object *, struct _jc_jas_ExceptAttr$object *);

// Virtual methods
extern void _jc_jas_Method$method$addGenericAttr$f87e320913bf4085(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_GenericAttr$object *);
extern void _jc_jas_Method$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_Method$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_Method$method_info$addGenericAttr$f87e320913bf4085;
extern _jc_method _jc_jas_Method$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_Method$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_Method$vmethods {
	void	(*addGenericAttr$f87e320913bf4085)(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_GenericAttr$object *);
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_Method$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Method$vmethods	jas_Method;
};

// Vtype
struct _jc_jas_Method$vtype {
	_jc_type			type;
	_jc_jas_Method$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_Method$sub_refs {
	struct _jc_jas_CP$object	*name;
	struct _jc_jas_CP$object	*sig;
	struct _jc_jas_CodeAttr$object	*code;
	struct _jc_jas_ExceptAttr$object	*excepts;
	struct _jc_java_util_Vector$object	*genericAttrs;
};

// Reference instance fields (object)
struct _jc_jas_Method$refs {
    _jc_jas_Method$sub_refs	jas_Method;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_Method$sub_nonrefs {
	jshort	acc;
};

// Non-reference instance fields (object)
struct _jc_jas_Method$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Method$sub_nonrefs	jas_Method;
};

// Object instance structure
struct _jc_jas_Method$object {
	_jc_jas_Method$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_Method$vtype	*vtype;
	_jc_jas_Method$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_Method$vtype _jc_jas_Method$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_Method, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_Method$class_object;

#endif	/* _JC_jas_Method_H_ */

==> jc-1.4.6.tar.gz: jas/Method.h <==
// public class jas.Method

// class file dependencies
// @dep_class fbdb68b05b612b08 jas_Method
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_jas_Method_H_
#define _JC_jas_Method_H_

// Forward structure declarations
struct _jc_jas_CP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_CodeAttr$object;
struct _jc_jas_ExceptAttr$object;
struct _jc_jas_GenericAttr$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_util_Vector$object;

// Typedefs
typedef struct _jc_jas_Method$sub_refs	_jc_jas_Method$sub_refs;
typedef struct _jc_jas_Method$sub_nonrefs	_jc_jas_Method$sub_nonrefs;
typedef struct _jc_jas_Method$refs	_jc_jas_Method$refs;
typedef struct _jc_jas_Method$nonrefs	_jc_jas_Method$nonrefs;
typedef struct _jc_jas_Method$object	_jc_jas_Method$object;

typedef const struct _jc_jas_Method$vmethods	_jc_jas_Method$vmethods;
typedef const struct _jc_jas_Method$vtable	_jc_jas_Method$vtable;
typedef const struct _jc_jas_Method$vtype	_jc_jas_Method$vtype;

// Constructors
extern void _jc_jas_Method$method$_init$1b6040d9f9d8340f(_jc_env *, struct _jc_jas_Method$object *, jshort, struct _jc_jas_CP$object *, struct _jc_jas_CP$object *, struct _jc_jas_CodeAttr$object *, struct _jc_jas_ExceptAttr$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_Method$method$addGenericAttr$f87e320913bf4085(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_GenericAttr$object *) _JC_JCNI_ATTR;
extern void _jc_jas_Method$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_Method$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_Method$method_info$addGenericAttr$f87e320913bf4085;
extern _jc_method _jc_jas_Method$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_Method$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_Method$vmethods {
	void	(*addGenericAttr$f87e320913bf4085)(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_GenericAttr$object *) _JC_JCNI_ATTR;
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_Method$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_Method$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_Method$vmethods	jas_Method;
};

// Vtype
struct _jc_jas_Method$vtype {
	_jc_type			type;
	_jc_jas_Method$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_Method$sub_refs {
	struct _jc_jas_CP$object	*name;
	struct _jc_jas_CP$object	*sig;
	struct _jc_jas_CodeAttr$object	*code;
	struct _jc_jas_ExceptAttr$object	*excepts;
	struct _jc_java_util_Vector$object	*genericAttrs;
};

// Reference instance fields (object)
struct _jc_jas_Method$refs {
    _jc_jas_Method$sub_refs	jas_Method;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_Method$sub_nonrefs {
	jshort	acc;
};

// Non-reference instance fields (object)
struct _jc_jas_Method$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_Method$sub_nonrefs	jas_Method;
};

// Object instance structure
struct _jc_jas_Method$object {
	_jc_jas_Method$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_Method$vtype	*vtype;
	_jc_jas_Method$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_Method$vtype _jc_jas_Method$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_Method, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_Method$class_object;

#endif	/* _JC_jas_Method_H_ */
